$Env:CONDA_EXE = "/opt/concourse/worker/volumes/live/1b321516-b0b2-4d5f-452d-8aa5ba7dafe9/volume/conda_1625030471846/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/conda"
$Env:_CE_M = ""
$Env:_CE_CONDA = ""
$Env:_CONDA_ROOT = "/opt/concourse/worker/volumes/live/1b321516-b0b2-4d5f-452d-8aa5ba7dafe9/volume/conda_1625030471846/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold"
$Env:_CONDA_EXE = "/opt/concourse/worker/volumes/live/1b321516-b0b2-4d5f-452d-8aa5ba7dafe9/volume/conda_1625030471846/_h_env_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold_placehold/bin/conda"
$CondaModuleArgs = @{ChangePs1 = $True}

Import-Module "$Env:_CONDA_ROOT\shell\condabin\Conda.psm1" -ArgumentList $CondaModuleArgs
Remove-Variable CondaModuleArgs